@@ -33,8 +33,6 @@
 
 typedef guint64 SeahorseVersion;
 
-#define SEAHORSE_BAD_FILENAME_CHARS  "/\\<>|:?;"
-
 gchar*      seahorse_util_get_date_string           (const time_t time);
 gchar*      seahorse_util_get_display_date_string   (const time_t time);
 
@@ -66,9 +64,6 @@ gboolean    seahorse_util_print_fd          (int fd,
 gboolean    seahorse_util_printf_fd         (int fd, 
                                              const char* data, ...);
 
-GFile *     seahorse_util_file_increment_unique     (GFile *file,
-                                                     guint *state);
-
 gboolean    seahorse_util_write_file_private            (const gchar* filename,
                                                          const gchar* contents,
                                                          GError **err);
