@@ -23,7 +23,6 @@
 #include "config.h"
 
 #include "seahorse-certificate.h"
-#include "seahorse-certificate-der-exporter.h"
 #include "seahorse-pkcs11.h"
 #include "seahorse-pkcs11-deleter.h"
 #include "seahorse-pkcs11-helpers.h"
@@ -32,11 +31,9 @@
 #include "seahorse-token.h"
 #include "seahorse-types.h"
 
-#include "seahorse-deletable.h"
-#include "seahorse-exportable.h"
+#include "seahorse-common.h"
 #include "seahorse-util.h"
 #include "seahorse-validity.h"
-#include "seahorse-viewable.h"
 
 #include <gcr/gcr.h>
 
@@ -173,11 +170,10 @@ calc_is_personal_and_trusted (SeahorseCertificate *self)
 			return SEAHORSE_FLAG_PERSONAL;
 	}
 
-	if (gcr_certificate_get_basic_constraints (GCR_CERTIFICATE (self), &is_ca, NULL) && is_ca)
-		return 0;
+	if (gcr_certificate_get_basic_constraints (GCR_CERTIFICATE (self), &is_ca, NULL))
+		return is_ca ? 0 : SEAHORSE_FLAG_PERSONAL;
 
-	/* The default for now */
-	return 0;
+	return SEAHORSE_FLAG_PERSONAL;
 }
 
 static void
@@ -357,21 +353,30 @@ static GList *
 seahorse_certificate_create_exporters (SeahorseExportable *exportable,
                                        SeahorseExporterType type)
 {
-	SeahorseExporter *exporter;
+	SeahorseCertificateDerExporter *exporter;
 	gboolean can_export = FALSE;
 
 	g_object_get (exportable, "exportable", &can_export, NULL);
 	if (!can_export)
 		return NULL;
 
-	exporter = seahorse_certificate_der_exporter_new (SEAHORSE_CERTIFICATE (exportable));
+	exporter = seahorse_certificate_der_exporter_new (GCR_CERTIFICATE (exportable));
 	return g_list_append (NULL, exporter);
 }
 
+static gboolean
+seahorse_certificate_get_exportable (SeahorseExportable *exportable)
+{
+	gboolean can;
+	g_object_get (exportable, "exportable", &can, NULL);
+	return can;
+}
+
 static void
 seahorse_certificate_exportable_iface (SeahorseExportableIface *iface)
 {
 	iface->create_exporters = seahorse_certificate_create_exporters;
+	iface->get_exportable = seahorse_certificate_get_exportable;
 }
 
 static SeahorseDeleter *
@@ -393,10 +398,19 @@ seahorse_certificate_create_deleter (SeahorseDeletable *deletable)
 	return deleter;
 }
 
+static gboolean
+seahorse_certificate_get_deletable (SeahorseDeletable *deletable)
+{
+	gboolean can;
+	g_object_get (deletable, "deletable", &can, NULL);
+	return can;
+}
+
 static void
 seahorse_certificate_deletable_iface (SeahorseDeletableIface *iface)
 {
 	iface->create_deleter = seahorse_certificate_create_deleter;
+	iface->get_deletable = seahorse_certificate_get_deletable;
 }
 
 static void
