@@ -21,6 +21,7 @@
 
 #include "config.h"
 
+#include "seahorse-pkcs11.h"
 #include "seahorse-pkcs11-backend.h"
 #include "seahorse-pkcs11-generate.h"
 #include "seahorse-token.h"
@@ -43,6 +44,8 @@ enum {
 	PROP_ACTIONS
 };
 
+void  seahorse_pkcs11_backend_initialize (void);
+
 static SeahorsePkcs11Backend *pkcs11_backend = NULL;
 
 struct _SeahorsePkcs11Backend {
@@ -58,7 +61,6 @@ struct _SeahorsePkcs11BackendClass {
 static const char *token_blacklist[] = {
 	"pkcs11:manufacturer=Gnome%20Keyring;serial=1:SSH:HOME",
 	"pkcs11:manufacturer=Gnome%20Keyring;serial=1:SECRET:MAIN",
-	"pkcs11:manufacturer=Gnome%20Keyring;serial=1%3aXDG%3aDEFAULT",
 	"pkcs11:manufacturer=Mozilla%20Foundation;token=NSS%20Generic%20Crypto%20Services",
 	NULL
 };
