@@ -217,7 +217,7 @@ seahorse_pkcs11_deleter_class_init (SeahorsePkcs11DeleterClass *klass)
 
 	deleter_class->add_object = seahorse_pkcs11_deleter_add_object;
 	deleter_class->create_confirm = seahorse_pkcs11_deleter_create_confirm;
-	deleter_class->delete_async = seahorse_pkcs11_deleter_delete_async;
+	deleter_class->delete = seahorse_pkcs11_deleter_delete_async;
 	deleter_class->delete_finish = seahorse_pkcs11_deleter_delete_finish;
 	deleter_class->get_objects = seahorse_pkcs11_deleter_get_objects;
 }
