@@ -29,8 +29,7 @@
 #include "seahorse-private-key.h"
 
 #include "seahorse-action.h"
-#include "seahorse-deleter.h"
-#include "seahorse-exportable.h"
+#include "seahorse-common.h"
 #include "seahorse-progress.h"
 #include "seahorse-util.h"
 
@@ -211,7 +210,7 @@ on_delete_objects (GtkAction *action,
 	}
 
 	if (seahorse_deleter_prompt (deleter, GTK_WINDOW (self))) {
-		seahorse_deleter_delete_async (deleter, NULL, on_delete_complete, g_object_ref (self));
+		seahorse_deleter_delete (deleter, NULL, on_delete_complete, g_object_ref (self));
 	}
 
 	g_object_unref (deleter);
@@ -358,7 +357,7 @@ seahorse_pkcs11_properties_constructed (GObject *obj)
 
 	if (SEAHORSE_IS_EXPORTABLE (self->object))
 		exporters = seahorse_exportable_create_exporters (SEAHORSE_EXPORTABLE (self->object),
-		                                                  SEAHORSE_EXPORTER_ANY);
+		                                                  SEAHORSE_EXPORTER_TYPE_ANY);
 
 	request = gtk_action_group_get_action (self->actions, "export-object");
 	gtk_action_set_visible (request, exporters != NULL);
